@@ -1,10 +1,10 @@
-from pathlib import Path
-
-from moderage.clients.client import ModeRageClient
-import uuid
+import os
 import shutil
+import uuid
+
 from tinydb import Query, TinyDB
 
+from moderage.clients.client import ModeRageClient
 from moderage.experiment import Experiment
 
 
@@ -13,9 +13,7 @@ class LocalClient(ModeRageClient):
     def __init__(self, cache_location, mr_service):
         super().__init__("Local Client", cache_location, mr_service)
 
-
-
-    def save(self, meta_category, meta, files=None, parents=None):
+    def save(self, meta_category, meta, files=None, parents=None, keep_originals=False):
         """
         Save using local tinydb and local cache only
         """
@@ -35,7 +33,7 @@ class LocalClient(ModeRageClient):
             cache_location.mkdir()
 
         # Move all the files into the cache
-        file_info_list = self._save_files(cache_location, files)
+        file_info_list = self._save_files(cache_location, files, keep_originals)
 
         entry = {
             'metaCategory': meta_category,
@@ -51,7 +49,7 @@ class LocalClient(ModeRageClient):
 
         return Experiment(entry, self._mr_service, experiment_cache_location)
 
-    def _save_files(self, cache_location, files):
+    def _save_files(self, cache_location, files, keep_originals):
         file_info_list = []
         if files is not None:
             for file in files:
@@ -62,13 +60,17 @@ class LocalClient(ModeRageClient):
                 file_info['contentType'] = file['contentType']
 
                 # Save the filename and strip the directory information
-                file_info['filename'] = Path(file['filename']).name
+                local_filename, uploaded_filename = self._process_filenames(file)
+                file_info['filename'] = uploaded_filename
 
                 # Save the location of the file in the filesystem
                 location = str(cache_location.joinpath(file_info['id']))
-                shutil.copy(file['filename'], location)
+                shutil.copy(local_filename, location)
                 file_info['location'] = location
                 file_info_list.append(file_info)
+
+                if not keep_originals:
+                    os.remove(local_filename)
         return file_info_list
 
     def load(self, id, meta_category, ignore_files=False):
@@ -121,8 +123,7 @@ class LocalClient(ModeRageClient):
         experiment_cache_location = self._get_experiment_cache_location(id, meta_category)
         return Experiment(search_result[0], self._mr_service, experiment_cache_location)
 
-
-    def add_files(self, id, meta_category, files):
+    def add_files(self, id, meta_category, files, keep_originals=False):
         """
 
         :param id:
@@ -142,7 +143,7 @@ class LocalClient(ModeRageClient):
         assert len(search_result) == 1
 
         # Save the files to the cache
-        file_info_list = self._save_files(meta_category_location, files)
+        file_info_list = self._save_files(meta_category_location, files, keep_originals)
 
         # Add the new files to the old files in the experiment
         experiment = search_result[0]
@@ -156,4 +157,4 @@ class LocalClient(ModeRageClient):
         assert len(search_result) == 1
 
         experiment_cache_location = meta_category_location.joinpath(id)
-        return Experiment(search_result[0], self._mr_service, experiment_cache_location=experiment_cache_location)
\ No newline at end of file
+        return Experiment(search_result[0], self._mr_service, experiment_cache_location=experiment_cache_location)
